@@ -27,6 +27,7 @@
 #include "config.h"
 #endif
 
+#include <locale.h>
 #include <stdlib.h>
 
 #include <glib.h>
@@ -65,6 +66,8 @@ main (int argc, char **argv)
         g_type_init ();
 #endif
 
+        setlocale (LC_ALL, "");
+
         ctx = g_option_context_new (" - program to list all the DLNA profiles supported by gupnp-dlna");
         g_option_context_add_main_entries (ctx, options, NULL);
         if (!g_option_context_parse (ctx, &argc, &argv, &err)) {
